S&P 500 Price, Real-time Quote & News - Google Finance
Description: Get the latest S&P 500 (.INX) value, historical performance, charts, and other financial information to help you make more informed trading and investment decisions.

Finance
Finance
Finance
finance_mode
Home
manage_search
Market trends
Portfolios
Create portfolio
Watchlists
Create watchlist
Most Active
Plug Power Inc
+16.67%
Intel Corp
+0.13%
NVIDIA Corp
+0.83%
Ondas Inc
+0.56%
Huntington Bancshares Inc
-6.02%
Immunitybio Inc
+6.07%
settings
Settings
feedback
Send feedback
Markets
US
Europe
Asia
Currencies
Crypto
Futures
Dow Jones
49,384.01
+0.63%
+306.78
Dow Jones
49,384.01
0.63%
S&P 500
6,913.35
+0.55%
+37.73
S&P 500
6,913.35
0.55%
Nasdaq
23,436.02
+0.91%
+211.20
Nasdaq
23,436.02
0.91%
Russell
2,718.77
+0.76%
+20.59
Russell
2,718.77
0.76%
VIX
15.64
-7.46%
-1.26
VIX
15.64
7.46%
Home
.INX • Index
Follow
S&P 500
6,913.35
Jan 22, 4:35:10 PM GMT-5 · INDEXSP · Disclaimer
Key events shows relevant news articles on days with large price movements
Key events shows relevant news articles on days with large price movements
Key events shows relevant news articles on days with large price movements
No data
Dow Jones Industrial Average
49,384.01
.DJI
0.63%
Russell 2000 Index
2,718.77
RUT
0.76%
FTSE 100 Index
10,150.05
UKX
0.12%
S&P/TSX Composite Index
33,002.70
OSPTX
0.46%
Nasdaq-100
25,518.35
NDX
0.76%
Nasdaq Composite
23,436.02
.IXIC
0.91%
VIX
15.64
VIX
7.46%
IBOVESPA
175,589.34
IBOV
2.20%
S&P/ASX 200
8,844.20
XJO
0.051%
EURO STOXX 50
5,956.17
SX5E
1.25%
stacked_line_chartIndex
A measure of the price performance of a collection of securities that are grouped to represent a certain market or sector
Previous close
The last closing price
6,875.62
Day range
The range between the high and low prices over the past day
6,893.62 - 6,934.75
Year range
The range between the high and low prices over the past 52 weeks
4,835.04 - 6,986.33
Top news
Crain's Cleveland Business
A 15-year investment in this group of Cleveland companies paid better than the S&P 500
2 hours ago
The Globe and Mail
The S&P 500 Hasn't Been This Expensive Since the Early 2000s. Is a Crash Inevitable in 2026?
2 hours ago
News about S&P 500, Trump, and Stock market
Yahoo Finance
Stock market today: Dow, S&P 500, Nasdaq futures rise after Trump backpedals on tariffs
9 hours ago
Yahoo Finance
Stock market today: Dow, S&P 500, Nasdaq rise after Trump backpedals on Greenland tariffs
3 hours ago
Barron's
Stock Market Today: Dow, S&P 500, Nasdaq Rise; Trump Greenland Tariffs; Intel, Netflix, Micron, Tesla, More Movers
1 hour ago
Vanguard S&P 500 ETF
The Motley Fool
Prediction: This Magnificent Vanguard ETF Will Beat the S&P 500 (Again) in 2026
13 hours ago
Yahoo Finance
Where Will the Vanguard S&P 500 ETF Be in 1 Year?
8 hours ago
Barron's
This Value Stock ETF Is Crushing the S&P 500. Here’s Its Secret Weapon.
3 hours ago
By the numbers
Sherwood News
GE Aerospace posts better-than-expected Q4 results and surprisingly strong full-year profit guidance
10 hours ago
FactSet Insight
S&P 500 Will Likely Report Double-Digit Earnings Growth For 5th Straight Quarter
2 days ago
The Wall Street Journal
Small Stocks Finish Week at Records
6 days ago
CNBC
1 day ago
S&P 500 pops 1%, Dow surges nearly 600 points as Trump calls off Europe tariffs tied to Greenland
NBC News
1 day ago
S&P 500 has its best day in two months after Trump backs off Greenland tariffs
About

S&P 500 is a stock market index tracking the stock performance of 500 leading companies listed on stock exchanges in the United States. It is one of the most commonly followed equity indices and includes approximately 80% of the total market capitalization of U.S. public companies, with an aggregate market cap of more than $61.1 trillion as of December 31, 2025. The S&P 500 index is a public float weighted/capitalization-weighted index. The ten largest companies on the list of S&P 500 companies account for approximately 38% of the market capitalization of the index and the 50 largest components account for 60% of the index. As of September 2025, the 10 largest components are, in order of highest to lowest weighting: Nvidia, Microsoft, Apple, Alphabet, Amazon, Meta Platforms, Broadcom, Tesla, Berkshire Hathaway, and JPMorgan Chase. The components that have increased their dividends in 25 consecutive years are known as the S&P 500 Dividend Aristocrats. Companies in the S&P 500 derive a collective 72% of revenues from the United States and 28% from other countries. Wikipedia
Discover more
You may be interested in
info
This list is generated from recent searches, followed securities, and other activity. Learn more
All data and information is provided “as is” for personal informational purposes only, and is not intended to be financial advice nor is it for trading purposes or investment, tax, legal, accounting or other advice. Google is not an investment adviser nor is it a financial adviser and expresses no view, recommendation or opinion with respect to any of the companies included in this list or any securities issued by those companies. Please consult your broker or financial representative to verify pricing before executing any trades. Learn more
Index
Dow Jones Industrial Average
49,384.01
0.63%
add_circle_outline
Index
S&P 500
6,913.35
0.55%
add_circle_outline
TSLA
Tesla Inc
$449.36
4.15%
add_circle_outline
AAPL
Apple Inc
$248.35
0.28%
add_circle_outline
BABA
Alibaba Group Holding Ltd - ADR
$177.18
5.05%
add_circle_outline
AMZN
Amazon.com Inc
$234.34
1.31%
add_circle_outline
Index
VIX
15.64
7.46%
add_circle_outline
NXST
Nexstar Media Group Inc
$219.27
3.23%
add_circle_outline
SPY
SPDR S&P 500 ETF Trust
$688.98
0.52%
add_circle_outline
MSFT
Microsoft Corp
$451.14
1.58%
add_circle_outline
F
Ford Motor Co
$13.71
0.44%
add_circle_outline
Index
Nasdaq Composite
23,436.02
0.91%
add_circle_outline
DIS
Walt Disney Co
$113.21
0.00%
add_circle_outline
NFLX
Netflix Inc
$83.54
2.13%
add_circle_outline
PFE
Pfizer Inc
$26.10
0.73%
add_circle_outline
T
AT&T Inc
$23.58
0.34%
add_circle_outline
Index
Nasdaq-100
25,518.35
0.76%
add_circle_outline
BA
Boeing Co
$251.41
0.54%
add_circle_outline
People also search for
Index
Dow Jones Industrial Average
49,384.01
0.63%
add_circle_outline
Index
Russell 2000 Index
2,718.77
0.76%
add_circle_outline
Index
FTSE 100 Index
10,150.05
0.12%
add_circle_outline
Index
S&P/TSX Composite Index
33,002.70
0.46%
add_circle_outline
Index
Nasdaq-100
25,518.35
0.76%
add_circle_outline
Index
Nasdaq Composite
23,436.02
0.91%
add_circle_outline
Index
VIX
15.64
7.46%
add_circle_outline
Index
IBOVESPA
175,589.34
2.20%
add_circle_outline
Index
S&P/ASX 200
8,844.20
0.051%
add_circle_outline
Index
EURO STOXX 50
5,956.17
1.25%
add_circle_outline
Index
IBEX 35
17,663.40
1.28%
add_circle_outline
Index
Nikkei 225
53,688.89
1.73%
add_circle_outline
Index
DAX PERFORMANCE-INDEX
24,856.47
1.20%
add_circle_outline
Index
TOPIX
3,616.38
0.74%
add_circle_outline
Index
S&P 400
3,521.86
0.075%
add_circle_outline
Index
NIFTY 50
25,289.90
0.53%
add_circle_outline
Index
CAC 40
8,148.89
0.99%
add_circle_outline
Index
STOXX Europe 600
608.86
1.03%
add_circle_outline
Search
Clear search
Close search
Google apps
Main menu